/*! For license information please see 31.bb01ea5d.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[31],{3890:function(e,t,r){"use strict";r.r(t),r.d(t,"default",(function(){return o}));var s=r(0),n=r(11),a=r(63),c=r(5);function o({element:e,width:t}){const r=Object(s.useRef)(null),o=e.type,i=e.url;Object(s.useEffect)((()=>{const t=r.current,s=()=>{t&&(t.currentTime=e.startTime)};return t&&t.addEventListener("loadedmetadata",s),()=>{t&&t.removeEventListener("loadedmetadata",s)}}),[e]);const l=t=>{const r=e.startTime;return r?"".concat(t,"?start=").concat(r):t};if(o===n.s.Type.YOUTUBE_IFRAME){const e=.75*t;return Object(c.jsx)("iframe",{title:i,src:l(i),width:t,height:e,frameBorder:"0",allow:"autoplay; encrypted-media",allowFullScreen:!0})}return Object(c.jsx)("video",{ref:r,controls:!0,src:Object(a.b)(i),className:"stVideo",style:{width:t}})}}}]);
//# sourceMappingURL=31.bb01ea5d.chunk.js.map