/*! For license information please see 37.692328a8.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[37],{3896:function(t,e,s){"use strict";s.r(e),s.d(e,"default",(function(){return l}));var i=s(0),n=s.n(i),a=s(196),r=s(5);class o extends n.a.PureComponent{constructor(...t){super(...t),this.state={value:this.initialValue},this.setWidgetValue=t=>{this.props.widgetMgr.setIntValue(this.props.element,this.state.value,t)},this.onChange=t=>{this.setState({value:t},(()=>this.setWidgetValue({fromUi:!0})))},this.render=()=>{const t=this.props.element,e=t.options,s=t.help,i=t.label,n=this.props.disabled;return Object(r.jsx)(a.b,{label:i,options:e,disabled:n,width:this.props.width,onChange:this.onChange,value:this.state.value,help:s})}}get initialValue(){const t=this.props.widgetMgr.getIntValue(this.props.element);return void 0!==t?t:this.props.element.default}componentDidMount(){this.setWidgetValue({fromUi:!1})}}var l=o}}]);
//# sourceMappingURL=37.692328a8.chunk.js.map