/*! For license information please see 20.b85230b4.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[20],{3751:function(t,e){},3881:function(t,e,i){"use strict";i.r(e),i.d(e,"default",(function(){return f}));i(0);var n=i(3727),r=i.n(n),o=i(293),a=i(63),c=i(8),s=i.n(c);const l=s()("div",{target:"etr89bj0"})((({theme:t})=>({display:"flex",flexDirection:"row",flexWrap:"wrap",rowGap:t.spacing.lg})),""),d=s()("div",{target:"etr89bj1"})((({theme:t})=>({display:"flex",flexDirection:"column",alignItems:"stretch",width:"auto",flexGrow:0})),""),h=s()("div",{target:"etr89bj2"})((({theme:t})=>({fontFamily:t.genericFonts.bodyFont,fontSize:t.fontSizes.smDefault,color:t.colors.fadedText60,textAlign:"center",marginTop:t.spacing.xs})),"");var u,m=i(5);!function(t){t[t.OriginalWidth=-1]="OriginalWidth",t[t.ColumnWidth=-2]="ColumnWidth",t[t.AutoWidth=-3]="AutoWidth"}(u||(u={}));var f=Object(o.a)((function({width:t,isFullScreen:e,element:i,height:n}){let o;const c=i.width;if(c===u.OriginalWidth||c===u.AutoWidth)o=void 0;else if(c===u.ColumnWidth)o=t;else{if(!(c>0))throw Error("Invalid image width: ".concat(c));o=c}const s={};return n&&e?(s.maxHeight=n,s["object-fit"]="contain"):(s.width=o,c===u.AutoWidth&&(s.maxWidth="100%")),Object(m.jsx)(l,{style:{width:t},children:i.imgs.map(((t,e)=>{const i=t;return Object(m.jsxs)(d,{"data-testid":"stImage",children:[i.markup?r()(Object(a.e)(i.markup)):Object(m.jsx)("img",{style:s,src:Object(a.b)(i.url),alt:e.toString()}),i.caption&&Object(m.jsx)(h,{"data-testid":"caption",children:" ".concat(i.caption," ")})]},e)}))})}))}}]);
//# sourceMappingURL=20.b85230b4.chunk.js.map