/*! For license information please see 25.ced03632.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[25],{3887:function(t,e,r){"use strict";r.r(e),r.d(e,"default",(function(){return a}));var i=r(0),s=r(3859),o=r(293),c=r(5);var a=Object(o.a)((function({width:t,element:e,index:r,height:o}){const a="bokeh-chart-".concat(r),h=Object(i.useCallback)((()=>JSON.parse(e.figure)),[e]),n=Object(i.useCallback)((r=>{const i=document.getElementById(a),c=r&&r.doc&&r.doc.roots&&r.doc.roots.references?r.doc.roots.references.find((t=>"Plot"===t.type)):void 0;if(c){const r=(r=>{let i=r.attributes.plot_width,s=r.attributes.plot_height;return o?(i=t,s=o):e.useContainerWidth&&(i=t),{chartWidth:i,chartHeight:s}})(c),i=r.chartWidth,s=r.chartHeight;i>0&&(c.attributes.plot_width=i),s>0&&(c.attributes.plot_height=s)}null!==i&&((t=>{for(;t.lastChild;)t.lastChild.remove()})(i),s.a.embed_item(r,a))}),[t,o,e,r]);return Object(i.useEffect)((()=>{n(h())}),[t,o,e,r,h,n]),Object(c.jsx)("div",{id:a,className:"stBokehChart"})}))}}]);
//# sourceMappingURL=25.ced03632.chunk.js.map