/*! For license information please see 15.0cfc668f.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[15],{3193:function(t,e){},3194:function(t,e){},3726:function(t,e){},3880:function(t,e,c){"use strict";c.r(e),c.d(e,"default",(function(){return g}));var h=c(0),i=c(3706),n=c(3724),r=c(12),a=c(293),o=c(8);const s=c.n(o)()("div",{target:"e1p558ko0"})((({theme:t})=>({"& *":{fontFamily:t.genericFonts.bodyFont,fontSize:"9.6px"},"& svg":{maxWidth:"100%"}})),"");var d=c(5);n.graphviz;var g=Object(a.a)((function({width:t,element:e,index:c,height:n}){const a="graphviz-chart-".concat(c);let o=0,g=0;const u=()=>{let c=g,h=o;return n?(c=t,h=n):e.useContainerWidth&&(c=t),{chartWidth:c,chartHeight:h}},p=()=>{try{const t=Object(i.select)("#".concat(a)).graphviz().zoom(!1).fit(!0).scale(1).renderDot(e.spec).on("end",(()=>{const t=Object(i.select)("#".concat(a," > svg")).node();t&&(o=t.getBBox().height,g=t.getBBox().width)})),c=u(),h=c.chartHeight,n=c.chartWidth;h>0&&t.height(h),n>0&&t.width(n)}catch(t){Object(r.b)(t)}};Object(h.useEffect)((()=>{p()}));const b=u(),f=b.chartWidth?b.chartWidth:t,l=b.chartHeight?b.chartHeight:n;return Object(d.jsx)(s,{className:"graphviz stGraphVizChart",id:a,style:{width:f,height:l}})}))}}]);
//# sourceMappingURL=15.0cfc668f.chunk.js.map