/*! For license information please see 27.4d40335f.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[27],{3888:function(t,e,r){"use strict";r.r(e),r.d(e,"default",(function(){return n}));var s=r(282),i=(r(0),r(5));function n({element:t,width:e}){const r=t.hasWidth?t.width:e;let n,c;t.scrolling?(n="auto",c={}):(n="no",c={overflow:"hidden"});const l=o(t.src),a=null!=l?void 0:o(t.srcdoc);return Object(i.jsx)("iframe",{allow:s.a,style:c,src:l,srcDoc:a,width:r,height:t.height,scrolling:n,sandbox:s.b,title:"st.iframe"})}function o(t){return null==t||""===t?void 0:t}}}]);
//# sourceMappingURL=27.4d40335f.chunk.js.map