/*! For license information please see 28.ca41fb3d.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[28],{3889:function(t,o,r){"use strict";r.r(o),r.d(o,"default",(function(){return i}));var e=r(6),a=(r(0),r(25)),c=r(293),n=r(3764),l=r.n(n),s=r(5);var i=Object(c.a)((function({width:t,element:o,height:r}){const c=()=>!!r,n=n=>{const l=JSON.parse(n.spec);c()?(l.layout.width=t,l.layout.height=r):o.useContainerWidth&&(l.layout.width=t);const s=Object(a.useTheme)();return l.layout=function(t,o){const r=o.colors,a=o.genericFonts,c={font:{color:r.bodyText,family:a.bodyFont},paper_bgcolor:r.bgColor,plot_bgcolor:r.secondaryBg};return Object(e.a)(Object(e.a)({},t),{},{font:Object(e.a)(Object(e.a)({},c.font),t.font),paper_bgcolor:t.paper_bgcolor||c.paper_bgcolor,plot_bgcolor:t.plot_bgcolor||c.plot_bgcolor})}(l.layout,s),l};switch(o.chart){case"url":return(o=>{const e=r||450,a=t;return Object(s.jsx)("iframe",{title:"Plotly",src:o,style:{width:a,height:e}})})(o.url);case"figure":return(t=>{const o=JSON.parse(t.config),r=n(t),e=r.data,a=r.layout,i=r.frames;return Object(s.jsx)(l.a,{className:"stPlotlyChart",data:e,layout:a,config:o,frames:i},c()?"fullscreen":"original")})(o.figure);default:throw new Error("Unrecognized PlotlyChart type: ".concat(o.chart))}}))}}]);
//# sourceMappingURL=28.ca41fb3d.chunk.js.map